@@ -8,11 +8,11 @@ from functools import lru_cache
 import os
 import subprocess
 from time import time, sleep
-
 from .csobject import CsObject
 from .protocol import rpc, MAGIC_NUMBER, UNITON_VERSION
 from .csutil import BrokenPromiseException
 
+
 TLIST = (
   (int, rpc.INT32, struct.Struct("i")),
   (float, rpc.FLOAT32, struct.Struct("f")),
@@ -97,51 +97,55 @@ class UnityProc:
         else:
           sleep(0.1) # wait, then repeat
 
-    self._sock.setsockopt(socket.IPPROTO_TCP, socket.TCP_NODELAY, 1)
-
+    # self._sock.setsockopt(socket.SOL_SOCKET, socket.SO_LINGER, struct.pack('ii', 1, 0))
 
     # bootstrap
-    self._sock.sendall(struct.pack("i", MAGIC_NUMBER))
 
+    # magic exchange
+    self._sock.sendall(struct.pack("i", MAGIC_NUMBER))
+    magic_number, = struct.unpack('i', recvall(self._sock, 4))
+    if magic_number != MAGIC_NUMBER:
+      raise ConnectionError("Could not connect.")
+    # bootstrap, = struct.unpack('i', recvall(self._sock, 4))
+
+    # if bootstrap:
     from importlib import resources
-    dll = resources.read_binary("uniton", "euniton.dll")
+    dll = resources.read_binary("uniton", "core.dll")
 
     self._sock.sendall(struct.pack("i", len(dll)))
     self._sock.sendall(dll)
-    self._sock.close()
+    # zero, = struct.unpack('i', recvall(self._sock, 4))  # wait for a 0 as confirmation (so we don't move on to quickly)
+    # assert zero == 0
 
 
+    # sleep(1)  # give the server some time to close and reopen the port
+    # self._sock.shutdown(socket.SHUT_WR)
+    # self._sock.recv(0)
 
-    sleep(1)  # Why do we need this?
+    # self._sock.close()
+    # print("closed, waiting..")
 
-    # connect again  TODO: obviously fix this redunancy
-    timeout = time() + 10
+    # sleep(4)  # We need to wait, otherwise we'll get "Adress already in use" on the server. I've tried to close the socket quicker but nothing worked.
+    #
+    #
+    # # reconnect now to core.dll
+    # self._sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+    # self._sock.connect((host, port))
 
-    while True:
-      try:
-        self._sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-        self._sock.connect((host, port))
-        break
-      except ConnectionRefusedError:
-        if not self._proc:
-          raise
-        elif self._proc.poll() is not None:
-          raise RuntimeError(f"Process {path} died before Uniton could connect!")
-        elif time() > timeout:
-          raise ConnectionRefusedError(f"Is {path} missing Uniton?")
-        else:
-          sleep(0.1)  # wait, then repeat
+    # self._sock.sendall(struct.pack("i", MAGIC_NUMBER))
+    # magic_number, = struct.unpack('i', recvall(self._sock, 4))
+    # if magic_number != MAGIC_NUMBER:
+    #   raise ConnectionError("Could not connect.")
+    # bootstrap, = struct.unpack('i', recvall(self._sock, 4))
+    # assert not bootstrap, "We should have already bootstrapped!"
 
-    self._sock.setsockopt(socket.IPPROTO_TCP, socket.TCP_NODELAY, 1)
+    #
+    # else:
+    #   print("Warning: This Uniton process has been connected to before. This could lead to strange behaviour.")
 
 
 
     # version compatibility check
-    magic_number, = struct.unpack('i', recvall(self._sock, 4))
-    if magic_number != MAGIC_NUMBER:
-      raise ConnectionError("Could not connect.")
-
-
     remote_version_tuple = struct.unpack('iii', recvall(self._sock, 4 * 3))
     self._remote_version = ".".join(str(x) for x in remote_version_tuple)
     local_version_macro = ".".join(UNITON_VERSION.split(".")[:2])
